@@ -15,6 +15,7 @@ import copy
 import serpentmonkee.UtilsMonkee as um
 from neo4j.exceptions import CypherSyntaxError, ServiceUnavailable, ClientError, ConstraintError
 from serpentmonkee.PubSubMonkee import PubSubMonkee
+from serpentmonkee.MonkeeSqlMessenger import MonkeeSQLblock, MonkeeSQLblockHandler
 import logging
 # --------------------------------------------------------------------
 
@@ -26,11 +27,12 @@ class CypherTransactionBlock:
                  transactionUid=None,
                  origin=None,
                  callingCF=None,
-                 sqlClient=None,
                  originDocUid=None,
-                 appUid=None):
+                 appUid=None,
+                 sqlBlockHandler=None):
         self.docUid = originDocUid
         self.appUid = appUid
+        self.sqlBlockHandler = sqlBlockHandler
         self.createdAt = datetime.now(timezone.utc)
         self.numRetries = 0
         self.lastUpdatedAt = datetime.now(timezone.utc)
@@ -45,7 +47,6 @@ class CypherTransactionBlock:
         self.callingCF = callingCF
         self.timeInQ = None
         self.setJson()
-        self.sqlClient = sqlClient
         self.qTable = 'monkee.q'
         self.qLogTable = 'monkee.q_log'
         self.registerChangeInSql('create')
@@ -99,178 +100,183 @@ class CypherTransactionBlock:
     def registerChangeInSql(self, newState, error=None):
         """
         Registers the change in the state of this CTB in the monkee.q table in SQL
+
         """
-        try:
-            if self.transactionUid is not None:
+
+        if self.transactionUid and self.sqlBlockHandler:
+            sqlInsertQuery = (
+                """ INSERT INTO """ + self.qLogTable + """(q_uid, status)
+            values ( %s,%s )
+            """
+            )
+            sqlInsertList = [self.transactionUid,
+                             newState]
+
+            sqlb = MonkeeSQLblock(query=sqlInsertQuery,
+                                  insertList=sqlInsertList,
+                                  queryTypeId='')
+            self.sqlBlockHandler.toQ(sqlb, priority='L')
+
+            if newState == 'create':
                 sqlInsertQuery = (
-                    """ INSERT INTO """ + self.qLogTable + """(q_uid, status)
-                values ( %s,%s )
-                """
+                    """ INSERT INTO """ + self.qTable + """(app_uid, uid, q_uid, ctb_serial, created_at, cf)
+                select %s,%s,%s,%s,%s,%s
+                where not exists (select * from """ + self.qTable + """ where q_uid=%s)"""
                 )
-                with self.sqlClient.connect() as conn:
-                    conn.execute(
-                        sqlInsertQuery,
-                        [
-                            self.transactionUid,
-                            newState
-                        ],
-                    )
+                sqlInsertList = [
+                    self.appUid,
+                    self.docUid,
+                    self.transactionUid,
+                    json.dumps(self.json, cls=um.RoundTripEncoder),
+                    self.createdAt,
+                    self.callingCF,
+                    self.transactionUid
+                ]
 
-                if newState == 'create':
-                    sqlInsertQuery = (
-                        """ INSERT INTO """ + self.qTable + """(app_uid, uid, q_uid, ctb_serial, created_at, cf)
-                    select %s,%s,%s,%s,%s,%s
-                    where not exists (select * from """ + self.qTable + """ where q_uid=%s)"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlInsertQuery,
-                            [
-                                self.appUid,
-                                self.docUid,
-                                self.transactionUid,
-                                json.dumps(self.json, cls=um.RoundTripEncoder),
-                                self.createdAt,
-                                self.callingCF,
-                                self.transactionUid
-                            ],
-                        )
-                elif newState == 'toWaiting':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET waiting_q_at = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+                sqlb = MonkeeSQLblock(query=sqlInsertQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='H')
 
-                            ],
-                        )
-                elif newState == 'toWorking':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET working_q_at = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+            elif newState == 'toWaiting':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET waiting_q_at = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
-                elif newState == 'toCompleted':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET compl_q_at = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+            elif newState == 'toWorking':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET working_q_at = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
-                elif newState == 'executeStart':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET exec_started_at = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+            elif newState == 'toCompleted':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET compl_q_at = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
-                elif newState == 'executeEnd':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET exec_completed_at = %s,
-                        errors = case when errors is not null then 'None. Original error = ' || errors else null end
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
-                            ],
-                        )
-                elif newState == 'error':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET errors = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                error,
-                                self.transactionUid
+            elif newState == 'executeStart':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET exec_started_at = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
-                elif newState == 'givenUp':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET errors = %s||'  '||errors
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                error,
-                                self.transactionUid
+            elif newState == 'executeEnd':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET exec_completed_at = %s,
+                    errors = case when errors is not null then 'None. Original error = ' || errors else null end
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
-                elif newState == 'outOfWorkingQ':
-                    sqlQuery = (
-                        """ UPDATE """ + self.qTable + """ 
-                        SET out_of_working_q_at = %s
-                        WHERE q_uid = %s"""
-                    )
-                    with self.sqlClient.connect() as conn:
-                        conn.execute(
-                            sqlQuery,
-                            [
-                                datetime.now(timezone.utc),
-                                self.transactionUid
+            elif newState == 'error':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET errors = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    error,
+                    self.transactionUid
+                ]
 
-                            ],
-                        )
-        except Exception as e:
-            logging.error("registerChangeInSql: {}".format(repr(e)))
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
+
+            elif newState == 'givenUp':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET errors = %s||'  '||errors
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    error,
+                    self.transactionUid
+                ]
+
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
+
+            elif newState == 'outOfWorkingQ':
+                sqlQuery = (
+                    """ UPDATE """ + self.qTable + """ 
+                    SET out_of_working_q_at = %s
+                    WHERE q_uid = %s"""
+                )
+                sqlInsertList = [
+                    datetime.now(timezone.utc),
+                    self.transactionUid
+                ]
+
+                sqlb = MonkeeSQLblock(query=sqlQuery,
+                                      insertList=sqlInsertList,
+                                      queryTypeId='')
+                self.sqlBlockHandler.toQ(sqlb, priority='L')
 
 
 class CypherTransactionBlockWorker:
-    def __init__(self, neoDriver, cypherQueues, sqlClient, pubsub):
+    def __init__(self, neoDriver, cypherQueues, pubsub, redisClient, environmentName):
         self.createdAt = datetime.now(timezone.utc)
         self.neoDriver = neoDriver
         self.cypherQueues = cypherQueues
-        self.sqlClient = sqlClient
         self.pubsub = pubsub
+        self.sqlBlockHandler = MonkeeSQLblockHandler(environmentName=environmentName,
+                                                     redis_client=redisClient,
+                                                     pubsub=pubsub.publisher)
 
     def goToWork(self, forHowLong=60, inactivityBuffer=10):
         print(f'XXX goToWork. ForHowLong={forHowLong}')
@@ -322,7 +328,7 @@ class CypherTransactionBlockWorker:
 
             print(f"Data read from waitingQ:{dataFromRedis}")
             ctb = CypherTransactionBlock(
-                priority=None, statements=None, transactionUid=None, origin=None, sqlClient=self.sqlClient)
+                priority=None, statements=None, transactionUid=None, origin=None, sqlBlockHandler=self.sqlBlockHandler)
             ctb.makeFromSerial(dataFromRedis)
             if ctb.statements:
                 ctb.lastUpdatedAt = datetime.now(timezone.utc)
@@ -342,7 +348,7 @@ class CypherTransactionBlockWorker:
         ser = self.cypherQueues.popCtbSerialFromWorkingQ()
         if ser:
             ctb = CypherTransactionBlock(
-                priority=None, statements=None, transactionUid=None, origin=None, sqlClient=self.sqlClient)
+                priority=None, statements=None, transactionUid=None, origin=None, sqlBlockHandler=self.sqlBlockHandler)
             ctb.makeFromSerial(ser)
             return ctb
         return None
@@ -351,7 +357,7 @@ class CypherTransactionBlockWorker:
         ser = self.cypherQueues.copyCtbSerialFromWorkingQ()
         if ser:
             ctb = CypherTransactionBlock(
-                priority=None, statements=None, transactionUid=None, origin=None, sqlClient=self.sqlClient)
+                priority=None, statements=None, transactionUid=None, origin=None, sqlBlockHandler=self.sqlBlockHandler)
             ctb.makeFromSerial(ser)
             return ctb
         return None
