@@ -24,6 +24,8 @@ from PubSubMonkee import PubSubMonkee
 from CypherTransaction import CypherTransactionBlock, CypherTransactionBlockWorker
 from CypherQueue import CypherQueue, CypherQueues
 
+from MonkeeSQLblockWorker import MonkeeSQLblockWorker
+
 
 # pip3 install neo4j==4.1.1
 # pip3 install neo4j==1.7.6
@@ -61,7 +63,7 @@ if __name__ == '__main__':
     sm = SecretMonkee(secretclient, project_id, ['neo']).getSecrets()
 
     neo_driver = NeoDriver(
-        neoDriver=None, redisClient=redis_client, sqlClient=sqldb, callingCF='neo_sync_interactionTemplates_v2', publisher=pubSubPublisher, topicId='cypher_worker', projectId=project_id)
+        neoDriver=None, redisClient=redis_client, callingCF='neo_sync_interactionTemplates_v2', publisher=pubSubPublisher, topicId='cypher_worker', projectId=project_id)
 
     neo_driver.makeNeoDriver(
         sm["neo_uri"], sm["neo_user"], sm["neo_pass"])
@@ -69,10 +71,9 @@ if __name__ == '__main__':
     neomnkee = NeoMonkee(
         neoDriver=neo_driver.neoDriver,
         redisClient=redis_client,
-        sqlClient=sqldb,
         callingCF='testingCF',
         publisher=pubSubPublisher,
-        topicId='testingProj',
+        topicId='cypher_worker',
         projectId=project_id,
         sqlTable='monkee.neo4j_queries')
 
@@ -118,6 +119,8 @@ if __name__ == '__main__':
         for r in res:
             print(r['uid'])
 
+        neomnkee.asyncWrite(priority='M', appUid='app', docUid='docc')
+
     redisClient = redis.Redis()
     cQH = CypherQueue("cypherQ_High")
     cQM = CypherQueue("cypherQ_Medium")
@@ -129,7 +132,15 @@ if __name__ == '__main__':
     cqs = CypherQueues(redisClient=redisClient,
                        cQueues=queues, workingQ=wQ, completedQ=compQ)
 
-    # cqs.killQueues()
+    cqs.killQueues()
+
+    topicId = 'cypher_worker'
+    pubsub = PubSubMonkee(pubSubPublisher, project_id, topicId)
+    w = CypherTransactionBlockWorker(
+        neoDriver=neomnkee.neoDriver, cypherQueues=cqs, pubsub=pubsub, redisClient=redis_client, environmentName=project_id)
+
+    sqlBlockHandler = w.sqlBlockHandler
+    sqlBlockHandler.killQueue()
 
     for i in range(0):
         statements = [
@@ -152,23 +163,24 @@ if __name__ == '__main__':
                 }
             },
         ]
+
         ctb = CypherTransactionBlock(priority='M',
                                      statements=statements,
                                      transactionUid=um.get_uuid(),
                                      origin='TEST',
                                      appUid='testApp',
                                      originDocUid='sflkjdf',
-                                     sqlClient=sqldb,
+                                     sqlBlockHandler=sqlBlockHandler,
                                      callingCF='testcf')
 
         cqs.pushCtbToWaitingQ(ctb)
 
     cqs.getQLens()
-
-    topicId = 'cypher_worker'
-    pubsub = PubSubMonkee(pubSubPublisher, project_id, topicId)
-    w = CypherTransactionBlockWorker(
-        neoDriver=neomnkee.neoDriver, cypherQueues=cqs, sqlClient=sqldb, pubsub=pubsub)
+    test_readWrite()
 
     w.goToWork(forHowLong=100)
     cqs.getQLens()
+
+    sqlWorker = MonkeeSQLblockWorker(
+        environmentName=project_id, sqlBHandler=sqlBlockHandler, sqlClient=sqldb)
+    sqlWorker.goToWork(forHowLong=600, batchSize=100)
